@@ -622,3 +622,33 @@ two_sided <- function(x, ...) {
 need_package <- function(x) {
   stop_wrap("You must have '", x, "' installed to use this function.")
 }
+
+when <- function(., ...) {
+    dots <- list(...)
+    names <- names(dots)
+    named <- if (is.null(names)) 
+        rep(FALSE, length(dots))
+    else names != ""
+    if (sum(!named) == 0) 
+        stop_wrap("At least one matching condition is needed.")
+    is_formula <- vapply(dots, function(dot) identical(class(dot), 
+        "formula"), logical(1L))
+    env <- new.env(parent = parent.frame())
+    env[["."]] <- .
+    if (sum(named) > 0) 
+        for (i in which(named)) env[[names[i]]] <- dots[[i]]
+    result <- NULL
+    for (i in which(!named)) {
+        if (is_formula[i]) {
+            action <- length(dots[[i]])
+            if (action == 2 || is_true(eval(dots[[i]][[2]], env, 
+                env))) {
+                result <- eval(dots[[i]][[action]], env, env)
+                break
+            }
+        } else {
+            result <- dots[[i]]
+        }
+    }
+    result
+}
